/**
 * @file
 * Attach behaviour for Live Content block.
 */
(function ($, Drupal, drupalSettings) {
  "use strict";
  Drupal.behaviors.live_content = {
    attach: function (context, settings) {
      let itemList = "#live-content-feed-items ul";
      // Connect to websocket server.
      const liveContentSettings = drupalSettings.live_content;
      const liveContentPort = liveContentSettings.hasOwnProperty('port') && liveContentSettings.port > 0 ? ':' + liveContentSettings.port : '';
      const wsConnection = new WebSocket(liveContentSettings.protocol + '://' + liveContentSettings.serverIP + liveContentPort);
      wsConnection.onmessage = (e) => {
        // Add a new item from the feed while keeping same total.
        $(itemList + " li:last", context).remove();
        $(itemList, context).prepend('<li>(' + Drupal.t('new') + ') ' + e.data + "</li>");
      };
      wsConnection.onerror = (e) => {
        throw Drupal.t('WebSocket live content error') + ': ' + e.data;
      }
    }
  };
})(jQuery, Drupal, drupalSettings);
